@@ -1,6 +1,6 @@
 from .src import *
 # Initialize environment (explicit wiring)
-def get_decode_rows(table=None,offset=None,ascending=None):
+def get_decode_rows(table=None,offset=None,asc=None):
     return get_latest_from_table(table=table,offset=offset,asc=asc)
 def decode_record_data(**kwargs):
     ENV = initializeEnvironment()
@@ -32,11 +32,11 @@ def decode_record_data(**kwargs):
             program_id=program_id,
             result=result
             )
-def decode_record_rows(rows=None,table=None,offset=None,ascending=None):
+def decode_record_rows(rows=None,table=None,offset=None,asc=None):
     rows = rows or get_decode_rows(
         table=table,
         offset=offset,
-        ascending=ascending
+        asc=asc
         )
     for row in make_list(rows):
         decode_record_data(**row)
